@@ -16,7 +16,7 @@
  */
 
 /*
- *  GiNaC Copyright (C) 1999-2025 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2026 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,8 +29,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "ginac.h"
@@ -460,7 +459,7 @@ static unsigned test_tree(const node tree_generator(unsigned))
 	// ...the sum, when evaluated and reexpanded, is the antipode...
 	ex result = 0;
 	for (vector<node>::iterator i=counter.begin(); i!=counter.end(); ++i)
-		result = (result+i->evaluate(x,vertices-1)).series(x==0,vertices-1).expand();
+		result = (result+i->evaluate(x,edges)).series(x==0,edges).expand();
 	
 	// ...and has the nice property that in each term all the Eulers cancel:
 	if (result.has(Euler)) {
