@@ -3,7 +3,7 @@
  *  Definition of optimizing macros. */
 
 /*
- *  GiNaC Copyright (C) 1999-2025 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2026 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef GINAC_COMPILER_H
@@ -26,12 +25,10 @@
 #ifdef __GNUC__
 #define unlikely(cond) __builtin_expect((cond), 0)
 #define likely(cond) __builtin_expect((cond), 1)
-#define attribute_deprecated __attribute__ ((deprecated))
 #define attribute_pure __attribute__((__pure__))
 #else
 #define unlikely(cond) (cond)
 #define likely(cond) (cond)
-#define attribute_deprecated
 #define attribute_pure
 #endif
 
