@@ -4,7 +4,7 @@
  *  somewhat obsolete (most of this can be replaced by exceptions). */
 
 /*
- *  GiNaC Copyright (C) 1999-2014 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2026 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef GINAC_FAIL_H
@@ -35,7 +34,7 @@ class fail : public basic
 	
 	// functions overriding virtual functions from base classes
 protected:
-	unsigned return_type() const { return return_types::noncommutative_composite; };
+	unsigned return_type() const override { return return_types::noncommutative_composite; };
 
 	// non-virtual functions in this class
 protected:
