@@ -3,7 +3,7 @@
  *  This include file includes all other public GiNaC headers. */
 
 /*
- *  GiNaC Copyright (C) 1999-2025 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2026 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef GINAC_H
@@ -72,6 +71,8 @@
 
 #include "excompiler.h"
 
+#include "Gt.h"
+
 #ifndef IN_GINAC
 #include "parser.h"
 #else
