@@ -3,7 +3,7 @@
  *  Implementation of symbolic matrices */
 
 /*
- *  GiNaC Copyright (C) 1999-2025 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2026 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "matrix.h"
@@ -1288,9 +1287,7 @@ int matrix::gauss_elimination(const bool det)
 					// yes, there is something to do in this row
 					ex piv = this->m[r2*n+c0] / this->m[r0*n+c0];
 					for (unsigned c=c0+1; c<n; ++c) {
-						this->m[r2*n+c] -= piv * this->m[r0*n+c];
-						if (!this->m[r2*n+c].info(info_flags::numeric))
-							this->m[r2*n+c] = this->m[r2*n+c].normal();
+						this->m[r2*n+c] = (this->m[r2*n+c] - piv * this->m[r0*n+c]).normal();
 					}
 				}
 				// fill up left hand side with zeros
