@@ -67,7 +67,7 @@
 
 
 /* First part of user prologue.  */
-#line 29 "ginsh_parser.ypp"
+#line 28 "ginsh_parser.ypp"
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -631,13 +631,13 @@ static const yytype_int8 yytranslate[] =
 /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_int16 yyrline[] =
 {
-       0,   145,   145,   146,   149,   150,   159,   167,   175,   189,
-     197,   205,   206,   207,   208,   209,   210,   211,   212,   213,
-     226,   227,   228,   229,   234,   235,   236,   236,   237,   238,
-     241,   242,   249,   250,   251,   252,   253,   254,   255,   263,
-     264,   272,   273,   274,   275,   276,   277,   278,   279,   280,
-     281,   282,   283,   284,   285,   286,   287,   288,   291,   292,
-     295,   296,   299,   300,   303,   304,   307,   308
+       0,   144,   144,   145,   148,   149,   158,   166,   174,   188,
+     196,   204,   205,   206,   207,   208,   209,   210,   211,   212,
+     224,   225,   226,   227,   232,   233,   234,   234,   235,   236,
+     239,   240,   247,   248,   249,   250,   251,   252,   253,   261,
+     262,   270,   271,   272,   273,   274,   275,   276,   277,   278,
+     279,   280,   281,   282,   283,   284,   285,   286,   289,   290,
+     293,   294,   297,   298,   301,   302,   305,   306
 };
 #endif
 
@@ -1309,7 +1309,7 @@ yyreduce:
   switch (yyn)
     {
   case 5: /* line: exp ';'  */
-#line 150 "ginsh_parser.ypp"
+#line 149 "ginsh_parser.ypp"
                   {
 		try {
 			cout << yyvsp[-1] << endl;
@@ -1323,7 +1323,7 @@ yyreduce:
     break;
 
   case 6: /* line: exp ':'  */
-#line 159 "ginsh_parser.ypp"
+#line 158 "ginsh_parser.ypp"
                   {
 		try {
 			push(yyvsp[-1]);
@@ -1336,7 +1336,7 @@ yyreduce:
     break;
 
   case 7: /* line: T_PRINT '(' exp ')' ';'  */
-#line 167 "ginsh_parser.ypp"
+#line 166 "ginsh_parser.ypp"
                                   {
 		try {
 			yyvsp[-2].print(print_tree(std::cout));
@@ -1349,7 +1349,7 @@ yyreduce:
     break;
 
   case 8: /* line: T_IPRINT '(' exp ')' ';'  */
-#line 175 "ginsh_parser.ypp"
+#line 174 "ginsh_parser.ypp"
                                    {
 		try {
 			ex e = yyvsp[-2];
@@ -1368,7 +1368,7 @@ yyreduce:
     break;
 
   case 9: /* line: T_PRINTLATEX '(' exp ')' ';'  */
-#line 189 "ginsh_parser.ypp"
+#line 188 "ginsh_parser.ypp"
                                        {
 		try {
 			yyvsp[-2].print(print_latex(std::cout)); cout << endl;
@@ -1381,7 +1381,7 @@ yyreduce:
     break;
 
   case 10: /* line: T_PRINTCSRC '(' exp ')' ';'  */
-#line 197 "ginsh_parser.ypp"
+#line 196 "ginsh_parser.ypp"
                                       {
 		try {
 			yyvsp[-2].print(print_csrc_double(std::cout)); cout << endl;
@@ -1394,55 +1394,55 @@ yyreduce:
     break;
 
   case 11: /* line: '?' T_SYMBOL  */
-#line 205 "ginsh_parser.ypp"
+#line 204 "ginsh_parser.ypp"
                                 {print_help(ex_to<symbol>(yyvsp[0]).get_name());}
 #line 1400 "ginsh_parser.cpp"
     break;
 
   case 12: /* line: '?' T_TIME  */
-#line 206 "ginsh_parser.ypp"
+#line 205 "ginsh_parser.ypp"
                                 {print_help("time");}
 #line 1406 "ginsh_parser.cpp"
     break;
 
   case 13: /* line: '?' T_PRINT  */
-#line 207 "ginsh_parser.ypp"
+#line 206 "ginsh_parser.ypp"
                                 {print_help("print");}
 #line 1412 "ginsh_parser.cpp"
     break;
 
   case 14: /* line: '?' T_IPRINT  */
-#line 208 "ginsh_parser.ypp"
+#line 207 "ginsh_parser.ypp"
                                 {print_help("iprint");}
 #line 1418 "ginsh_parser.cpp"
     break;
 
   case 15: /* line: '?' T_PRINTLATEX  */
-#line 209 "ginsh_parser.ypp"
+#line 208 "ginsh_parser.ypp"
                                 {print_help("print_latex");}
 #line 1424 "ginsh_parser.cpp"
     break;
 
   case 16: /* line: '?' T_PRINTCSRC  */
-#line 210 "ginsh_parser.ypp"
+#line 209 "ginsh_parser.ypp"
                                 {print_help("print_csrc");}
 #line 1430 "ginsh_parser.cpp"
     break;
 
   case 17: /* line: '?' '?'  */
-#line 211 "ginsh_parser.ypp"
+#line 210 "ginsh_parser.ypp"
                                 {print_help_topics();}
 #line 1436 "ginsh_parser.cpp"
     break;
 
   case 18: /* line: T_QUIT  */
-#line 212 "ginsh_parser.ypp"
+#line 211 "ginsh_parser.ypp"
                                 {YYACCEPT;}
 #line 1442 "ginsh_parser.cpp"
     break;
 
   case 19: /* line: T_WARRANTY  */
-#line 213 "ginsh_parser.ypp"
+#line 212 "ginsh_parser.ypp"
                      {
 		cout << "This program is free software; you can redistribute it and/or modify it under\n";
 		cout << "the terms of the GNU General Public License as published by the Free Software\n";
@@ -1453,84 +1453,83 @@ yyreduce:
 		cout << "FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more\n";
 		cout << "details.\n";
 		cout << "You should have received a copy of the GNU General Public License along with\n";
-		cout << "this program. If not, write to the Free Software Foundation,\n";
-		cout << "51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.\n";
+		cout << "this program.  If not, see <https://www.gnu.org/licenses/>.\n";
 	}
-#line 1460 "ginsh_parser.cpp"
+#line 1459 "ginsh_parser.cpp"
     break;
 
   case 20: /* line: T_XYZZY  */
-#line 226 "ginsh_parser.ypp"
+#line 224 "ginsh_parser.ypp"
                                 {cout << "Nothing happens.\n";}
-#line 1466 "ginsh_parser.cpp"
+#line 1465 "ginsh_parser.cpp"
     break;
 
   case 21: /* line: T_INVENTORY  */
-#line 227 "ginsh_parser.ypp"
+#line 225 "ginsh_parser.ypp"
                                 {cout << "You're not carrying anything.\n";}
-#line 1472 "ginsh_parser.cpp"
+#line 1471 "ginsh_parser.cpp"
     break;
 
   case 22: /* line: T_LOOK  */
-#line 228 "ginsh_parser.ypp"
+#line 226 "ginsh_parser.ypp"
                                 {cout << "You're in a twisty little maze of passages, all alike.\n";}
-#line 1478 "ginsh_parser.cpp"
+#line 1477 "ginsh_parser.cpp"
     break;
 
   case 23: /* line: T_SCORE  */
-#line 229 "ginsh_parser.ypp"
+#line 227 "ginsh_parser.ypp"
                   {
 		cout << "If you were to quit now, you would score ";
 		cout << (syms.size() > 350 ? 350 : syms.size());
 		cout << " out of a possible 350.\n";
 	}
-#line 1488 "ginsh_parser.cpp"
+#line 1487 "ginsh_parser.cpp"
     break;
 
   case 24: /* line: T_REAL_SYMBOLS  */
-#line 234 "ginsh_parser.ypp"
+#line 232 "ginsh_parser.ypp"
                          { symboltype = domain::real; }
-#line 1494 "ginsh_parser.cpp"
+#line 1493 "ginsh_parser.cpp"
     break;
 
   case 25: /* line: T_COMPLEX_SYMBOLS  */
-#line 235 "ginsh_parser.ypp"
+#line 233 "ginsh_parser.ypp"
                             { symboltype = domain::complex; }
-#line 1500 "ginsh_parser.cpp"
+#line 1499 "ginsh_parser.cpp"
     break;
 
   case 26: /* $@1: %empty  */
-#line 236 "ginsh_parser.ypp"
+#line 234 "ginsh_parser.ypp"
                  { START_TIMER }
-#line 1506 "ginsh_parser.cpp"
+#line 1505 "ginsh_parser.cpp"
     break;
 
   case 27: /* line: T_TIME $@1 '(' exp ')'  */
-#line 236 "ginsh_parser.ypp"
+#line 234 "ginsh_parser.ypp"
                                              { STOP_TIMER PRINT_TIME_USED }
-#line 1512 "ginsh_parser.cpp"
+#line 1511 "ginsh_parser.cpp"
     break;
 
   case 28: /* line: error ';'  */
-#line 237 "ginsh_parser.ypp"
+#line 235 "ginsh_parser.ypp"
                                 {yyclearin; yyerrok;}
-#line 1518 "ginsh_parser.cpp"
+#line 1517 "ginsh_parser.cpp"
     break;
 
   case 29: /* line: error ':'  */
-#line 238 "ginsh_parser.ypp"
+#line 236 "ginsh_parser.ypp"
                                 {yyclearin; yyerrok;}
-#line 1524 "ginsh_parser.cpp"
+#line 1523 "ginsh_parser.cpp"
     break;
 
   case 30: /* exp: T_NUMBER  */
-#line 241 "ginsh_parser.ypp"
+#line 239 "ginsh_parser.ypp"
                                 {yyval = yyvsp[0];}
-#line 1530 "ginsh_parser.cpp"
+#line 1529 "ginsh_parser.cpp"
     break;
 
   case 31: /* exp: T_SYMBOL  */
-#line 242 "ginsh_parser.ypp"
+#line 240 "ginsh_parser.ypp"
                                 {
 		auto i = assigned_symbol_table.find(yyvsp[0]);
 		if (i == assigned_symbol_table.end())
@@ -1538,47 +1537,47 @@ yyreduce:
 		else
 			yyval = i->second;
 	}
-#line 1542 "ginsh_parser.cpp"
+#line 1541 "ginsh_parser.cpp"
     break;
 
   case 32: /* exp: '\'' T_SYMBOL '\''  */
-#line 249 "ginsh_parser.ypp"
+#line 247 "ginsh_parser.ypp"
                                 {yyval = yyvsp[-1];}
-#line 1548 "ginsh_parser.cpp"
+#line 1547 "ginsh_parser.cpp"
     break;
 
   case 33: /* exp: T_LITERAL  */
-#line 250 "ginsh_parser.ypp"
+#line 248 "ginsh_parser.ypp"
                                 {yyval = yyvsp[0];}
-#line 1554 "ginsh_parser.cpp"
+#line 1553 "ginsh_parser.cpp"
     break;
 
   case 34: /* exp: T_DIGITS  */
-#line 251 "ginsh_parser.ypp"
+#line 249 "ginsh_parser.ypp"
                                 {yyval = yyvsp[0];}
-#line 1560 "ginsh_parser.cpp"
+#line 1559 "ginsh_parser.cpp"
     break;
 
   case 35: /* exp: T_QUOTE  */
-#line 252 "ginsh_parser.ypp"
+#line 250 "ginsh_parser.ypp"
                                 {yyval = exstack[0];}
-#line 1566 "ginsh_parser.cpp"
+#line 1565 "ginsh_parser.cpp"
     break;
 
   case 36: /* exp: T_QUOTE2  */
-#line 253 "ginsh_parser.ypp"
+#line 251 "ginsh_parser.ypp"
                                 {yyval = exstack[1];}
-#line 1572 "ginsh_parser.cpp"
+#line 1571 "ginsh_parser.cpp"
     break;
 
   case 37: /* exp: T_QUOTE3  */
-#line 254 "ginsh_parser.ypp"
+#line 252 "ginsh_parser.ypp"
                                 {yyval = exstack[2];}
-#line 1578 "ginsh_parser.cpp"
+#line 1577 "ginsh_parser.cpp"
     break;
 
   case 38: /* exp: T_SYMBOL '(' exprseq ')'  */
-#line 255 "ginsh_parser.ypp"
+#line 253 "ginsh_parser.ypp"
                                    {
 		auto i = find_function(yyvsp[-3], yyvsp[-1].nops());
 		if (i->second.is_ginac) {
@@ -1587,17 +1586,17 @@ yyreduce:
 			yyval = (i->second.p)(ex_to<exprseq>(yyvsp[-1]));
 		}
 	}
-#line 1591 "ginsh_parser.cpp"
+#line 1590 "ginsh_parser.cpp"
     break;
 
   case 39: /* exp: T_DIGITS '=' T_NUMBER  */
-#line 263 "ginsh_parser.ypp"
+#line 261 "ginsh_parser.ypp"
                                 {yyval = yyvsp[0]; Digits = ex_to<numeric>(yyvsp[0]).to_int();}
-#line 1597 "ginsh_parser.cpp"
+#line 1596 "ginsh_parser.cpp"
     break;
 
   case 40: /* exp: T_SYMBOL '=' exp  */
-#line 264 "ginsh_parser.ypp"
+#line 262 "ginsh_parser.ypp"
                                 {
 		yyval = yyvsp[0];
 		const exmap m{{yyvsp[-2], yyvsp[0]}};
@@ -1606,173 +1605,173 @@ yyreduce:
 		}
 		assigned_symbol_table[yyvsp[-2]] = yyvsp[0];
 	}
-#line 1610 "ginsh_parser.cpp"
+#line 1609 "ginsh_parser.cpp"
     break;
 
   case 41: /* exp: exp T_EQUAL exp  */
-#line 272 "ginsh_parser.ypp"
+#line 270 "ginsh_parser.ypp"
                                 {yyval = yyvsp[-2] == yyvsp[0];}
-#line 1616 "ginsh_parser.cpp"
+#line 1615 "ginsh_parser.cpp"
     break;
 
   case 42: /* exp: exp T_NOTEQ exp  */
-#line 273 "ginsh_parser.ypp"
+#line 271 "ginsh_parser.ypp"
                                 {yyval = yyvsp[-2] != yyvsp[0];}
-#line 1622 "ginsh_parser.cpp"
+#line 1621 "ginsh_parser.cpp"
     break;
 
   case 43: /* exp: exp '<' exp  */
-#line 274 "ginsh_parser.ypp"
+#line 272 "ginsh_parser.ypp"
                                 {yyval = yyvsp[-2] < yyvsp[0];}
-#line 1628 "ginsh_parser.cpp"
+#line 1627 "ginsh_parser.cpp"
     break;
 
   case 44: /* exp: exp T_LESSEQ exp  */
-#line 275 "ginsh_parser.ypp"
+#line 273 "ginsh_parser.ypp"
                                 {yyval = yyvsp[-2] <= yyvsp[0];}
-#line 1634 "ginsh_parser.cpp"
+#line 1633 "ginsh_parser.cpp"
     break;
 
   case 45: /* exp: exp '>' exp  */
-#line 276 "ginsh_parser.ypp"
+#line 274 "ginsh_parser.ypp"
                                 {yyval = yyvsp[-2] > yyvsp[0];}
-#line 1640 "ginsh_parser.cpp"
+#line 1639 "ginsh_parser.cpp"
     break;
 
   case 46: /* exp: exp T_GREATEREQ exp  */
-#line 277 "ginsh_parser.ypp"
+#line 275 "ginsh_parser.ypp"
                                 {yyval = yyvsp[-2] >= yyvsp[0];}
-#line 1646 "ginsh_parser.cpp"
+#line 1645 "ginsh_parser.cpp"
     break;
 
   case 47: /* exp: exp '+' exp  */
-#line 278 "ginsh_parser.ypp"
+#line 276 "ginsh_parser.ypp"
                                 {yyval = yyvsp[-2] + yyvsp[0];}
-#line 1652 "ginsh_parser.cpp"
+#line 1651 "ginsh_parser.cpp"
     break;
 
   case 48: /* exp: exp '-' exp  */
-#line 279 "ginsh_parser.ypp"
+#line 277 "ginsh_parser.ypp"
                                 {yyval = yyvsp[-2] - yyvsp[0];}
-#line 1658 "ginsh_parser.cpp"
+#line 1657 "ginsh_parser.cpp"
     break;
 
   case 49: /* exp: exp '*' exp  */
-#line 280 "ginsh_parser.ypp"
+#line 278 "ginsh_parser.ypp"
                                 {yyval = yyvsp[-2] * yyvsp[0];}
-#line 1664 "ginsh_parser.cpp"
+#line 1663 "ginsh_parser.cpp"
     break;
 
   case 50: /* exp: exp '/' exp  */
-#line 281 "ginsh_parser.ypp"
+#line 279 "ginsh_parser.ypp"
                                 {yyval = yyvsp[-2] / yyvsp[0];}
-#line 1670 "ginsh_parser.cpp"
+#line 1669 "ginsh_parser.cpp"
     break;
 
   case 51: /* exp: '-' exp  */
-#line 282 "ginsh_parser.ypp"
+#line 280 "ginsh_parser.ypp"
                                 {yyval = -yyvsp[0];}
-#line 1676 "ginsh_parser.cpp"
+#line 1675 "ginsh_parser.cpp"
     break;
 
   case 52: /* exp: '+' exp  */
-#line 283 "ginsh_parser.ypp"
+#line 281 "ginsh_parser.ypp"
                                 {yyval = yyvsp[0];}
-#line 1682 "ginsh_parser.cpp"
+#line 1681 "ginsh_parser.cpp"
     break;
 
   case 53: /* exp: exp '^' exp  */
-#line 284 "ginsh_parser.ypp"
+#line 282 "ginsh_parser.ypp"
                                 {yyval = power(yyvsp[-2], yyvsp[0]);}
-#line 1688 "ginsh_parser.cpp"
+#line 1687 "ginsh_parser.cpp"
     break;
 
   case 54: /* exp: exp '!'  */
-#line 285 "ginsh_parser.ypp"
+#line 283 "ginsh_parser.ypp"
                                 {yyval = factorial(yyvsp[-1]);}
-#line 1694 "ginsh_parser.cpp"
+#line 1693 "ginsh_parser.cpp"
     break;
 
   case 55: /* exp: '(' exp ')'  */
-#line 286 "ginsh_parser.ypp"
+#line 284 "ginsh_parser.ypp"
                                 {yyval = yyvsp[-1];}
-#line 1700 "ginsh_parser.cpp"
+#line 1699 "ginsh_parser.cpp"
     break;
 
   case 56: /* exp: '{' list_or_empty '}'  */
-#line 287 "ginsh_parser.ypp"
+#line 285 "ginsh_parser.ypp"
                                 {yyval = yyvsp[-1];}
-#line 1706 "ginsh_parser.cpp"
+#line 1705 "ginsh_parser.cpp"
     break;
 
   case 57: /* exp: '[' matrix ']'  */
-#line 288 "ginsh_parser.ypp"
+#line 286 "ginsh_parser.ypp"
                                 {yyval = lst_to_matrix(ex_to<lst>(yyvsp[-1]));}
-#line 1712 "ginsh_parser.cpp"
+#line 1711 "ginsh_parser.cpp"
     break;
 
   case 58: /* exprseq: exp  */
-#line 291 "ginsh_parser.ypp"
+#line 289 "ginsh_parser.ypp"
                                 {yyval = exprseq{yyvsp[0]};}
-#line 1718 "ginsh_parser.cpp"
+#line 1717 "ginsh_parser.cpp"
     break;
 
   case 59: /* exprseq: exprseq ',' exp  */
-#line 292 "ginsh_parser.ypp"
+#line 290 "ginsh_parser.ypp"
                                 {exprseq es(ex_to<exprseq>(yyvsp[-2])); yyval = es.append(yyvsp[0]);}
-#line 1724 "ginsh_parser.cpp"
+#line 1723 "ginsh_parser.cpp"
     break;
 
   case 60: /* list_or_empty: %empty  */
-#line 295 "ginsh_parser.ypp"
+#line 293 "ginsh_parser.ypp"
                                 {yyval = *new lst;}
-#line 1730 "ginsh_parser.cpp"
+#line 1729 "ginsh_parser.cpp"
     break;
 
   case 61: /* list_or_empty: list  */
-#line 296 "ginsh_parser.ypp"
+#line 294 "ginsh_parser.ypp"
                                 {yyval = yyvsp[0];}
-#line 1736 "ginsh_parser.cpp"
+#line 1735 "ginsh_parser.cpp"
     break;
 
   case 62: /* list: exp  */
-#line 299 "ginsh_parser.ypp"
+#line 297 "ginsh_parser.ypp"
                                 {yyval = lst{yyvsp[0]};}
-#line 1742 "ginsh_parser.cpp"
+#line 1741 "ginsh_parser.cpp"
     break;
 
   case 63: /* list: list ',' exp  */
-#line 300 "ginsh_parser.ypp"
+#line 298 "ginsh_parser.ypp"
                                 {lst l(ex_to<lst>(yyvsp[-2])); yyval = l.append(yyvsp[0]);}
-#line 1748 "ginsh_parser.cpp"
+#line 1747 "ginsh_parser.cpp"
     break;
 
   case 64: /* matrix: '[' row ']'  */
-#line 303 "ginsh_parser.ypp"
+#line 301 "ginsh_parser.ypp"
                                 {yyval = lst{yyvsp[-1]};}
-#line 1754 "ginsh_parser.cpp"
+#line 1753 "ginsh_parser.cpp"
     break;
 
   case 65: /* matrix: matrix ',' '[' row ']'  */
-#line 304 "ginsh_parser.ypp"
+#line 302 "ginsh_parser.ypp"
                                  {lst l(ex_to<lst>(yyvsp[-4])); yyval = l.append(yyvsp[-1]);}
-#line 1760 "ginsh_parser.cpp"
+#line 1759 "ginsh_parser.cpp"
     break;
 
   case 66: /* row: exp  */
-#line 307 "ginsh_parser.ypp"
+#line 305 "ginsh_parser.ypp"
                                 {yyval = lst{yyvsp[0]};}
-#line 1766 "ginsh_parser.cpp"
+#line 1765 "ginsh_parser.cpp"
     break;
 
   case 67: /* row: row ',' exp  */
-#line 308 "ginsh_parser.ypp"
+#line 306 "ginsh_parser.ypp"
                                 {lst l(ex_to<lst>(yyvsp[-2])); yyval = l.append(yyvsp[0]);}
-#line 1772 "ginsh_parser.cpp"
+#line 1771 "ginsh_parser.cpp"
     break;
 
 
-#line 1776 "ginsh_parser.cpp"
+#line 1775 "ginsh_parser.cpp"
 
       default: break;
     }
@@ -1965,7 +1964,7 @@ yyreturnlab:
   return yyresult;
 }
 
-#line 316 "ginsh_parser.ypp"
+#line 314 "ginsh_parser.ypp"
 
 // Error print routine
 int yyerror(const char *s)
@@ -2104,6 +2103,12 @@ static ex f_integral(const exprseq &e)
 	return GiNaC::integral(e[0], e[1], e[2], e[3]);
 }
 
+static ex f_Gt(const exprseq &e)
+{
+	CHECK_ARG(0, lst, Gt);
+	return GiNaC::Gt(e[0], e[1], e[2]);
+}
+
 static ex f_inverse(const exprseq &e)
 {
 	CHECK_ARG(0, matrix, inverse);
@@ -2218,6 +2223,57 @@ static ex f_subs3(const exprseq &e)
 	return e[0].subs(ex_to<lst>(e[1]), ex_to<lst>(e[2]));
 }
 
+
+static ex f_Gt_evaluate(const exprseq &e) {
+	CHECK_ARG(1, lst, Gt_evaluate);
+	if(is_a<lst>(e[0]))
+		return Gt::lst_evaluate(ex_to<lst>(e[0]), ex_to<lst>(e[1]));
+	else
+		return Gt::ex_evaluate(e[0], ex_to<lst>(e[1]));
+}
+static ex f_Gt_enableTauToFundamental(const exprseq &e) {
+	CHECK_ARG(0, numeric, Gt_enableTauToFundamental);
+	Gt::enable_tauToFundamental = !ex_to<numeric>(e[0]).is_zero();
+	cout << "Gt::enable_tauToFundamental set to " << Gt::enable_tauToFundamental << endl;
+	return numeric(0);
+}
+static ex f_Gt_setCutThresholds(const exprseq &e) {
+	CHECK_ARG(0, numeric, Gt_setCutThresholds);
+	CHECK_ARG(1, numeric, Gt_setCutThresholds);
+	const numeric n_real = ex_to<numeric>(e[0]), n_imag = ex_to<numeric>(e[1]);
+	if(!(n_real.is_real() && 0 < n_real && n_real < 0.5 && n_imag.is_real() && 0 < n_imag && n_imag < 0.5))
+		throw std::runtime_error("Invalid arguments passed to Gt_setCutThresholds");
+	Gt::cutIntegrationPath_threshold_real = n_real.to_double();
+	Gt::cutIntegrationPath_threshold_imag = n_imag.to_double();
+	cout << "Gt::cutIntegrationPath_threshold_real set to " << Gt::cutIntegrationPath_threshold_real << endl;
+	cout << "Gt::cutIntegrationPath_threshold_imag set to " << Gt::cutIntegrationPath_threshold_imag << endl;
+	return numeric(0);
+}
+static ex f_Gt_prepare(const exprseq &e) {
+	CHECK_ARG(1, lst, f_Gt_prepare);
+	return Gt::ex_prepare(e[0], ex_to<lst>(e[1]));
+}
+static ex f_Gt_zisToFundamental(const exprseq &e) {
+	CHECK_ARG(1, lst, f_Gt_zisToFundamental);
+	return Gt::ex_zisToFundamental(e[0], ex_to<lst>(e[1]));
+}
+static ex f_Gt_regularise(const exprseq &e) {
+	CHECK_ARG(1, lst, f_Gt_regularise);
+	return Gt::ex_regularise(e[0], ex_to<lst>(e[1]));
+}
+static ex f_Gt_tauToFundamental(const exprseq &e) {
+	CHECK_ARG(1, lst, f_Gt_tauToFundamental);
+	return Gt::ex_tauToFundamental(e[0], ex_to<lst>(e[1]));
+}
+static ex f_Gt_cutIntegrationPath(const exprseq &e) {
+	CHECK_ARG(1, lst, f_Gt_cutIntegrationPath);
+	return Gt::ex_cutIntegrationPath(e[0], ex_to<lst>(e[1]));
+}
+static ex f_Gt_qExpand(const exprseq &e) {
+	CHECK_ARG(1, lst, f_Gt_qExpand);
+	return Gt::ex_qExpand(e[0], ex_to<lst>(e[1]));
+}
+
 static ex f_trace(const exprseq &e)
 {
 	CHECK_ARG(0, matrix, trace);
@@ -2382,6 +2438,7 @@ static const fcn_init builtin_fcns[] = {
 	{"has", f_has, 2},
 	{"integer_content", f_integer_content, 1},
 	{"integral", f_integral, 4},
+	{"Gt", f_Gt, 3},
 	{"inverse", f_inverse, 1},
 	{"iprint", f_dummy, 0},      // for Tab-completion
 	{"is", f_is, 1},
@@ -2415,6 +2472,15 @@ static const fcn_init builtin_fcns[] = {
 	{"sqrt", f_sqrt, 1},
 	{"subs", f_subs2, 2},
 	{"subs", f_subs3, 3},
+	{"Gt_evaluate", f_Gt_evaluate, 2},
+	{"Gt_enableTauToFundamental", f_Gt_enableTauToFundamental, 1},
+	{"Gt_setCutThresholds", f_Gt_setCutThresholds, 2},
+	{"Gt_prepare", f_Gt_prepare, 2},
+	{"Gt_zisToFundamental", f_Gt_zisToFundamental, 2},
+	{"Gt_regularise", f_Gt_regularise, 2},
+	{"Gt_tauToFundamental", f_Gt_tauToFundamental, 2},
+	{"Gt_cutIntegrationPath", f_Gt_cutIntegrationPath, 2},
+	{"Gt_qExpand", f_Gt_qExpand, 2},
 	{"tcoeff", f_tcoeff, 2},
 	{"time", f_dummy, 0},        // for Tab-completion
 	{"trace", f_trace, 1},
@@ -2471,6 +2537,7 @@ static const fcn_help_init builtin_help[] = {
 	{"tanh", "hyperbolic tangent function"},
 	{"zeta", "zeta function\nzeta(x) is Riemann's zeta function, zetaderiv(n,x) its nth derivative.\nIf x is a GiNaC::lst, it is a multiple zeta value\nzeta(x,s) is an alternating Euler sum"},
 	{"G", "multiple polylogarithm (integral representation)"},
+	{"Gt", "elliptic multiple polylogarithm (integral representation)"},
 	{"Li2", "dilogarithm"},
 	{"Li3", "trilogarithm"},
 	{"Li", "(multiple) polylogarithm"},
@@ -2672,7 +2739,7 @@ static void ginsh_readline_init(char* name)
 void greeting(void)
 {
     cout << "ginsh - GiNaC Interactive Shell (GiNaC V" << GINACLIB_VERSION << ")" << endl;
-    cout << "  __,  _______  Copyright (C) 1999-2025 Johannes Gutenberg University Mainz,\n"
+    cout << "  __,  _______  Copyright (C) 1999-2026 Johannes Gutenberg University Mainz,\n"
          << " (__) *       | Germany.  This is free software with ABSOLUTELY NO WARRANTY.\n"
          << "  ._) i N a C | You are welcome to redistribute it under certain conditions.\n"
          << "<-------------' For details type `warranty;'.\n" << endl;
